@@ -17,6 +17,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/bep/clock"
 	"github.com/spf13/cast"
 
 	toml "github.com/pelletier/go-toml/v2"
@@ -74,6 +75,8 @@ var (
 		"November",
 		"December",
 	}
+
+	Clock = clock.System()
 )
 
 func NewTimeFormatter(ltr locales.Translator) TimeFormatter {
@@ -148,3 +151,13 @@ func ToTimeInDefaultLocationE(i any, location *time.Location) (tim time.Time, er
 	}
 	return cast.ToTimeInDefaultLocationE(i, location)
 }
+
+// Now returns time.Now() or time value based on the `clock` flag.
+// Use this function to fake time inside hugo.
+func Now() time.Time {
+	return Clock.Now()
+}
+
+func Since(t time.Time) time.Duration {
+	return Clock.Since(t)
+}
